fn view_and_relay_commit<T: Committable>(
view: ViewNumber,
relay: u64,
epoch: Option<EpochNumber>,
tag: &str,
) -> Commitment<T>Expand description
This implements commit for all the types which contain a view and relay public key.
fn view_and_relay_commit<T: Committable>(
view: ViewNumber,
relay: u64,
epoch: Option<EpochNumber>,
tag: &str,
) -> Commitment<T>This implements commit for all the types which contain a view and relay public key.